from __future__ import annotations

from .FXComposite import FXComposite


class FXSrollArea(FXComposite): ...
